# Bitmovin Analytics Collector

[![CircleCI](https://dl.circleci.com/status-badge/img/gh/bitmovin-engineering/bitmovin-analytics-collector/tree/main.svg?style=shield&circle-token=e3ec1c4b9bcaf4bb4818dc6f234845f2807137cc)](https://dl.circleci.com/status-badge/redirect/gh/bitmovin-engineering/bitmovin-analytics-collector/tree/main)
[![install size](https://packagephobia.com/badge?p=bitmovin-analytics)](https://packagephobia.com/result?p=bitmovin-analytics)

Instruments adaptive streaming video players and collects information to be sent to the Bitmovin Analytics service.

To get started collecting data with Bitmovin Analytics you need a License-Key which you can get for free by signing up for a [free Bitmovin account](https://bitmovin.com/dashboard/signup).

## Supported Players

The supported video players are shown here: [Analytics Collectors - HTML5](https://developer.bitmovin.com/playback/docs/analytics-collectors#html5-collectors)

## Usage

[A getting started guide](https://developer.bitmovin.com/playback/docs/setup-analytics-web#bitmovin-player) on how to integrate Bitmovin Analytics Collector with the Bitmovin Player is available on our homepage.

For more comprehensive integration documentation please consult the [Bitmovin Analytics documentation](https://developer.bitmovin.com/playback/docs/setup-analytics).

### Integrating Bitmovin 8

Bitmovin Player v8 comes with Analtyics pre-installed and just requires an `analytics` section containing your license key in the player configuration.

A minimal example:

```js
const configWithAnalytics = {
  key: '<YOUR PLAYER KEY>',
  analytics: {
    key: '<YOUR ANALYITICS KEY>',
    videoId: 'VIDEO_ID',
  },
};

const container = document.getElementById('my-player');
const player = bitmovin.player.Player(container, configWithAnalytics);
```

To ensure you are running a specific version (e.g. when including the `bitmovin-analytics` package from NPM) override the built-in analytics module:

Using `script` tag:

```js
<script type="text/javascript" src="https://cdn.bitmovin.com/analytics/web/2/bitmovinanalytics.min.js"></script>;
bitmovin.player.Player.addModule(bitmovin.analytics.PlayerModule);
```

Using `npm`:

```js
import {Player} from 'bitmovin-player/modules/bitmovinplayer-core';
import {PlayerModule as AnalyticsModule} from 'bitmovin-analytics';
Player.addModule(AnalyticsModule);
```

### Integrating 3rd Party Players

To integrate other players pick the appropriate adapter (`HlsAdapter`, `VideojsAdapter`, `ShakaAdapter`, `DashjsAdapter` or `HTMLVideoElementAdapter`) and instantiate the adapter by passing the player instance.

An example for HLS.js:

```js
const analyticsConfig = {
  key: '<YOUR ANALYITICS KEY>',
  videoId: 'VIDEO_ID',
};

const player = new Hls();
const analytics = new bitmovin.analytics.adapters.HlsAdapter(config, player);

player.loadSource('https://path.to/your/stream.m3u8');
player.attachMedia(document.getElementById('video'));
```

Before changing the video source in the player, you need to call `sourceChange()` on the assotiated analytics adapter. You can pass new configuration properties to this method like `videoId` or `videoTitle`

```js
analytics.sourceChange({
  videoID: 'new-video-id',
  videoTitle: 'New Video',
});

// Load the new source into player
```
